@@ -232,7 +232,15 @@ ergm <- function(formula, response=NULL,
     }
   }else control$init <- rep(NA, length(model.initial$etamap$offsettheta)) # Set the default value of control$init.
 
-  if(!is.null(offset.coef)) control$init[model.initial$etamap$offsettheta]<-offset.coef
+  if(!is.null(offset.coef)){
+      # TODO: Names matching here?
+      if(length(control$init[model.initial$etamap$offsettheta])!=length(offset.coef))
+          stop("Invalid offset parameter vector offset.coef: ",
+               "wrong number of parameters: expected ",
+               length(control$init[model.initial$etamap$offsettheta]),
+               " got ",length(offset.coef),".")
+      control$init[model.initial$etamap$offsettheta]<-offset.coef
+  }
   
   # Make sure any offset elements are given in control$init.
   if(any(is.na(control$init) & model.initial$etamap$offsettheta)) stop("The model contains offset terms whose parameter values have not been specified:", paste.and(model.initial$coef.names[is.na(control$init)|model.initial$offsettheta]), ".", sep="")
@@ -328,7 +336,7 @@ ergm <- function(formula, response=NULL,
   if (verbose) cat("Fitting ERGM.\n")
   mainfit <- switch(control$main.method,
     "Robbins-Monro" = ergm.robmon(init, nw, model, 
-                      MHproposal(constraints,weights=control$MCMC.prop.weights, control$MCMC.prop.args, nw, response=response), verbose, control),
+      MHproposal=MHproposal, verbose=verbose, control=control),
     "Stochastic-Approximation" = ergm.stocapprox(init, nw, model, 
                                  control=control, MHproposal=MHproposal,
                                  verbose),
