@@ -1,16 +1,42 @@
-#  File ergm/R/ergm.phase12.R
-#  Part of the statnet package, http://statnet.org
+#  File R/ergm.phase12.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
 ###############################################################################
 # The <ergm.phase12> function is a wrapper for the <MCMC.phase12.C> method,
 # which collects a sample of networks and returns the matrix of summary
 # statistics
+#
+# --PARAMETERS--
+#   g         : a network object
+#   model     : a model for 'g', as returned by <ergm.getmodel>
+#   MHproposal: an MHproposal object, as returned by <MHproposal>
+#   eta0      : the vector of initial eta coefficients
+#   control: a list of control parameters for the MCMC algorithm;
+#               recognized components include:
+#                     'maxedges'     'samplesize'     'gain'
+#                     'stats'        'phase1'         'nsub'
+#                     'burnin'       'interval'       'target.stats'
+#               the purpose of most of these variables is given in the
+#               <control.ergm> function header; 'stats' seems to be
+#                used as the mean statistics; 'target.stats' is merely
+#                returned.
+#   verbose   : whether the C functions should be verbose (T or F)
+#
+# --RETURNED--
+#   a list containing
+#     statsmatrix: the matrix of summary statistics
+#     newnetwork : the final network sampled
+#     target.stats  : the 'target.stats' from 'control'
+#     maxedges   : the 'maxedges' from 'control'
+#     eta        : the parameters used to produce the sample given
+#                  by 'statsmatrix'
+#
 ###############################################################################
 
 ergm.phase12 <- function(g, model,
@@ -45,7 +71,7 @@ ergm.phase12 <- function(g, model,
             as.integer(Clist$nterms), 
             as.character(Clist$fnamestring),
             as.character(Clist$snamestring),
-            as.character(MHproposal$name), as.character(MHproposal$package),
+            as.character(MHproposal$name), as.character(MHproposal$pkgname),
             as.double(Clist$inputs),
             eta=as.double(eta0),
             as.integer(control$MCMC.samplesize),
