@@ -1,14 +1,15 @@
-#  File ergm/tests/ergm.mixed.R
-#  Part of the statnet package, http://statnet.org
+#  File tests/ergm.mixed.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
-library(ergm)                                        #
-
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(ergm)
+opttest({
+library(statnet.common)
 # import synthetic network that looks like a molecule
 data(molecule)
 set.vertex.attribute(molecule,"atomic type",c(1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3,3))
@@ -29,3 +30,4 @@ gest <- ergm(molecule ~ edges + kstar(2) + triangle + nodematch("atomic type",di
 # mixed=TRUE,
              control=control.ergm(MCMC.samplesize=10000))
 summary(gest)
+}, "ergm mixed")
