@@ -1,17 +1,16 @@
-#  File ergm/tests/flomarkov.R
-#  Part of the statnet package, http://statnetproject.org
+#  File tests/flomarkov.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(statnet.common)
+opttest({
 library(ergm)
 #
-# Use 'data(package = "ergm")' to list the data sets in a
-data(package="ergm")
-#
 # Load a graph object of the Florentine data
 #
 data(florentine)
@@ -31,3 +30,4 @@ summary(gest)
 #
 gest <- ergm(flomarriage ~ kstar(1:2) + absdiff("wealth") + triangle)
 summary(gest)
+}, "Florentine Markov graph")
