@@ -1,14 +1,15 @@
-#  File ergm/tests/mple_largenetwork.R
-#  Part of the statnet package, http://statnetproject.org
+#  File tests/mple_largenetwork.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(statnet.common)
+opttest({
 library(ergm)
-
 # Note:  n can be made larger if a more stringent test is desired
 
 # First, a test for sparse networks with n edges, so the
@@ -38,7 +39,4 @@ for(n in 500) { # n should be a multiple of 100
   }
   cat(paste("Passed second MPLE test for n =",n))
 }
-
-
-
-
+},"MPLE for large networks")
