@@ -1,12 +1,14 @@
-#  File ergm/tests/runtime_diags.R
-#  Part of the statnet package, http://statnet.org
+#  File tests/runtime_diags.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(statnet.common)
+opttest({
 library(ergm)
 data(florentine)
 
@@ -18,3 +20,4 @@ gest <- ergm(flomarriage ~ kstar(1:2) + absdiff("wealth") + triangle,
 
 gest <- ergm(flomarriage ~ kstar(1:2) + absdiff("wealth") + triangle,
              control=control.ergm(MCMC.runtime.traceplot=TRUE))
+}, "runtime diagnostics")
